@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2005 Zope Foundation and Contributors.
+# Copyright (c) 2005 Zope Corporation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -13,7 +13,7 @@
 ##############################################################################
 """Mechanize-based Functional Doctest interfaces
 
-$Id: browser.py 124525 2012-03-05 20:59:15Z menesis $
+$Id: browser.py 109680 2010-03-05 15:56:34Z fdrake $
 """
 
 __docformat__ = "reStructuredText"
@@ -218,21 +218,16 @@ class Browser(SetattrErrorsMixin):
 
         def get(self):
             headers = self.mech_browser.addheaders
-            value = dict(headers).get(header_key, True)
-            return {'False': False}.get(value, True)
+            return dict(headers).get(header_key, True)
 
         def set(self, value):
             headers = self.mech_browser.addheaders
             current_value = get(self)
             if current_value == value:
                 return
-
-            # Remove the current header...
-            for key, header_value in headers[:]:
-                if key == header_key:
-                    headers.remove((key, header_value))
-            # ... Before adding the new one.
-            headers.append((header_key, {False: 'False'}.get(value, 'True')))
+            if header_key in dict(headers):
+                headers.remove((header_key, current_value))
+            headers.append((header_key, value))
 
         return property(get, set)
 
@@ -333,6 +328,10 @@ class Browser(SetattrErrorsMixin):
         args['nr'] = index
         return Link(self.mech_browser.find_link(**args), self)
 
+    def follow(self, *args, **kw):
+        """Select a link and follow it."""
+        self.getLink(*args, **kw).click()
+
     def _findByLabel(self, label, forms, include_subcontrols=False):
         # forms are iterable of mech_forms
         matches = re.compile(r'(^|\b|\W)%s(\b|\W|$)'
