@@ -1,10 +1,10 @@
 ##############################################################################
 #
-# Copyright (c) 2004 Zope Foundation and Contributors.
+# Copyright (c) 2004 Zope Corporation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
-# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
+# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
@@ -13,7 +13,7 @@
 ##############################################################################
 """Real test for file-upload and beginning of a better internal test framework
 
-$Id: tests.py 124525 2012-03-05 20:59:15Z menesis $
+$Id: tests.py 110919 2010-04-15 01:34:33Z tseaver $
 """
 
 from zope.app.testing.functional import FunctionalDocFileSuite
@@ -165,9 +165,10 @@ class Browser(zope.testbrowser.browser.Browser):
         mech_browser = FauxMechanizeBrowser()
         super(Browser, self).__init__(url=url, mech_browser=mech_browser)
 
-    def open(self, body, headers=None, status=200, reason='OK'):
+    def open(self, body, headers=None, status=200, reason='OK',
+             url='http://localhost/'):
         set_next_response(body, headers, status, reason)
-        zope.testbrowser.browser.Browser.open(self, 'http://localhost/')
+        zope.testbrowser.browser.Browser.open(self, url)
 
 def test_submit_duplicate_name():
     """
@@ -377,6 +378,58 @@ Also, if there is some other whitespace after the start tag, it will be preserve
     '  Foo  '
     """
 
+def test_relative_link():
+    """
+    RFC 1808 specifies how relative URLs should be resolved, let's see
+    that we conform to it. Let's start with a simple example.
+
+    >>> browser = Browser()
+    >>> browser.open('''\
+    ... <html><body>
+    ...     <a href="foo">link</a>
+    ... </body></html>
+    ... ''', url='http://localhost/bar') # doctest: +ELLIPSIS
+    GET /bar HTTP/1.1
+    ...
+
+    >>> link = browser.getLink('link')
+    >>> link.url
+    'http://localhost/foo'
+
+    It's possible to have a relative URL consisting of only a query part. In
+    that case it should simply be appended to the base URL.
+
+    >>> browser.open('''\
+    ... <html><body>
+    ...     <a href="?key=value">link</a>
+    ... </body></html>
+    ... ''', url='http://localhost/bar') # doctest: +ELLIPSIS
+    GET /bar HTTP/1.1
+    ...
+
+    >>> link = browser.getLink('link')
+    >>> link.url
+    'http://localhost/bar?key=value'
+
+    In the example above, the base URL was the page URL, but we can also
+    specify a base URL using a <base> tag.
+
+    >>> browser.open('''\
+    ... <html><head><base href="http://localhost/base" /></head><body>
+    ...     <a href="?key=value">link</a>
+    ... </body></html>
+    ... ''', url='http://localhost/base/bar') # doctest: +ELLIPSIS
+    GET /base/bar HTTP/1.1
+    ...
+
+    >>> link = browser.getLink('link')
+    >>> link.url
+    'http://localhost/base?key=value'
+
+    """
+
+
+
 class win32CRLFtransformer(object):
     def sub(self, replacement, text):
         return text.replace(r'\r','')
@@ -391,7 +444,8 @@ checker = zope.testing.renormalizing.RENormalizing([
     (re.compile(r'Content-[Ll]ength:.*'), 'Content-Length: 123'),
     (re.compile(r'Status: 200.*'), 'Status: 200 OK'),
     (win32CRLFtransformer(), None),
-    (re.compile(r'User-Agent: Python-urllib/2.[567]'), 'User-agent: Python-urllib/2.4'),
+    (re.compile(r'User-Agent: Python-urllib/2.5'), 'User-agent: Python-urllib/2.4'),
+    (re.compile(r'User-Agent: Python-urllib/2.6'), 'User-agent: Python-urllib/2.4'),
     (re.compile(r'Host: localhost'), 'Connection: close'),
     (re.compile(r'Content-Type: '), 'Content-type: '),
     (re.compile(r'Content-Disposition: '), 'Content-disposition: '),
